@@ -1,4 +1,4 @@
-/* $Id: httpd.c,v 1.11 2005/12/10 13:15:55 ichiro Exp $ */
+/* $Id: httpd.c,v 1.19 2005/12/11 20:23:46 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -69,7 +69,7 @@ httpd(gpointer param)
 			printf("error: accepting a socket.\n");
 			exit (1);
 		}
-		usleep(10000);
+		usleep(100000);
 		httpd_proc(th2, s3);
 
 		close(s3);
@@ -210,7 +210,7 @@ void httpd_proc(struct tparam *th2, int socket)
 #endif
 		/* wait for flags clear */
 		while ((!th2->t_empty) || (th2->t_lock)) {
-			usleep(10000); /* 100ms */
+			usleep(10000); /* 10ms */
 		}
 		th2->t_lock = 1;	/* now writing */
 
@@ -218,17 +218,27 @@ void httpd_proc(struct tparam *th2, int socket)
 		if ((s = strstr(buf, "Content-Length: ")))
 			post_length = atoi(s + 16);
 
+		/* if cannot read 'm=' or 'cname=', read more */
+		if((!strstr(buf, "m=")) && (!strstr(buf, "cname=")))
+			read(socket, buf, post_length);
+
 		/* Get post message */
 		if ((s = strstr(buf, "m="))) {
 			sprintf(post_message, "%.*s",
 				post_length - 2, s + 2);
 
+			if (post_length < 3) {
+				/* clear trans. empty flag */
+				th2->t_empty = 0;
+                                th2->t_lock = 0;
+                                goto index_start;
+			}
+
 			/* URL decord */
 #ifdef DEBUG
 			printf("decode: %s\n", post_message);
 #endif
-			if (url_decode_jis(post_message2, post_message))
-				goto index_start;
+			url_decode_jis(post_message2, post_message);
 
 			/* Get channel number to post */
 			sscanf(uri_addr + 1, "channel%d",
@@ -254,55 +264,51 @@ void httpd_proc(struct tparam *th2, int socket)
 			memset(cmd_cmd, 0, sizeof(cmd_cmd));    
 			memset(cmd_topic, 0, sizeof(cmd_topic));
 
-			sprintf(post_message,
+			sprintf(post_message,	/* XXX temporary used */
 				"%.*s", post_length, s);
 
 			q = strtok(post_message, "&");
 				if (q != NULL) strcpy(cmd_cname, q + 6);
+					/* 6: cname= */
 			if (strstr(buf, "cmd=")) {
 				q = strtok(NULL, "&");
 				if (q != NULL) {
 					strcpy(cmd_cmd, q + 4);
+					/* 4: cmd= */
 				}
 			}
 			q = strtok(NULL, "&");
 			if (q != NULL) {
 				strcpy(cmd_buf, q + 5);
+					/* 5: toto= */
 			}
 
 			/* make command message */
 			if (strcmp(cmd_cmd, "join") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
-				sprintf(post_message, ":%s JOIN %s\r\n",
+				sprintf(th2->postdata, ":%s JOIN %s\r\n",
 					th2->real_nickname,
 					channel2);
 			} else if (strcmp(cmd_cmd, "part") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
-				sprintf(post_message, ":%s PART %s\r\n",
+				sprintf(th2->postdata, ":%s PART %s\r\n",
 					th2->real_nickname,
 					channel2);
+			} else if (strcmp(cmd_cmd, "nick") == 0) {
+				sprintf(th2->postdata, ":%s NICK %s\r\n",
+					th2->real_nickname, cmd_buf);
 			} else if (strcmp(cmd_cmd, "topic") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
 				url_decode_jis(cmd_topic, cmd_buf);
-				sprintf(post_message, ":%s TOPIC %s :%s\r\n",
+				sprintf(th2->postdata, ":%s TOPIC %s :%s\r\n",
 					th2->real_nickname,
 					channel2, cmd_topic);
-			} else if (strcmp(cmd_cmd, "list") == 0) {
-				if (strlen(cmd_cname) > 0) {
-				    url_decode_rawdata(channel, cmd_cname);
-				    channel_decode(channel2, channel);
-				    sprintf(post_message, "NAMES %s\r\n",
-					    channel2); 
-				}
 			} else {
 				goto command_start;
 			}
-
-			/* transfer message */
-			strcpy(th2->postdata, post_message);
 		}
 
 		/* clear trans lock and empty flag */
@@ -393,7 +399,7 @@ index_start:
 		send_msg(socket,
 			 "<input type=submit value=\" $BAw?.(B \"></form>");
 		send_msg(socket,
-			"<a accesskey=\"8\" href=\"../\">back[8]</a><hr>");
+			"<a accesskey=\"8\" href=\"/\">back[8]</a><hr>");
 
 		if (update)
 			start_number = th2->read_count[number];
@@ -479,17 +485,17 @@ void print_command_page(int socket)
 	   "<input type=\"submit\" \
 		accesskey=\"1\" value=\"OK[1]\">");
 	send_msg(socket,
-	   "<a accesskey=\"8\" href=\"../\"> back[8]</a><hr>");
+	   "<a accesskey=\"8\" href=\"/\"> back[8]</a><hr>");
 	send_msg(socket,
 	   "channel <input type=text name=\"cname\" size=\"10\">");
 	send_msg(socket,
 	   "<br><input type=radio name=\"cmd\" value=\"join\">JOIN");
 	send_msg(socket,
 	   "<br><input type=radio name=\"cmd\" value=\"part\">PART");
-	send_msg(socket,
-	   "<br><input type=radio name=\"cmd\" value=\"list\">USER update");
 	send_msg(socket,
 	   "<br><input type=radio name=\"cmd\" value=\"topic\">TOPIC");
+	send_msg(socket,
+	   "<br><input type=radio name=\"cmd\" value=\"nick\">NICK");
 	send_msg(socket,
 	   "<input type=text name=\"toto\" size=\"7\"></form>");
 }
