@@ -1,4 +1,4 @@
-/* $Id: httpd.h,v 1.2 2004/12/04 12:52:50 ichiro Exp $ */
+/* $Id: httpd.h,v 1.4 2005/12/09 15:45:18 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -32,8 +32,11 @@
  * SUCH DAMAGE.
  */
 
-static char http_header1[] = {
+static char http_header0[] = {
 	"HTTP/1.1 200 OK\r\n"
+};
+
+static char http_header1[] = {
 	"Content-type: text/html\r\n"
 	"\r\n"
 };
@@ -46,7 +49,6 @@ static char http_header2[] = {
 };
 
 static char ico_header10[] = {
-	"HTTP/1.0 200 OK\r\n"
 	"Content-type: image/x-icon\r\n"
 	"\r\n"
 };
