@@ -1,4 +1,4 @@
-/* $Id: keitai.c,v 1.11 2005/12/10 13:09:55 ichiro Exp $ */
+/* $Id: keitai.c,v 1.22 2005/12/11 20:17:58 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -38,6 +38,7 @@
 #include <ctype.h>
 #include <errno.h>
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #include <arpa/inet.h>
@@ -49,7 +50,7 @@
 int
 keitai_start(struct tparam *th)
 {
-	char a1[40], a2[40], a3[40], a4[IRC_MAX];
+	char a1[IRC_MAX], a2[IRC_MAX], a3[IRC_MAX * 2], a4[IRC_MAX * 2];
 	char *s;
 
 #ifdef DEBUG
@@ -61,14 +62,12 @@ keitai_start(struct tparam *th)
 
 	/* catch PING messages */
 	if ((s = strstr(th->l_buff, "PING"))) {
-		sscanf(th->l_buff, "PING :%[^\n]", a1);
-		ping_recv(th, a1);
+		ping_recv(th);
 	}
 
 	/* catch NICK name */
 	if ((s = strstr(th->l_buff, "NICK"))) {
-		sscanf(th->l_buff, ":%*s NICK :%[^,]", a3);
-		strcpy(th->real_nickname, a3);
+		nick_recv(th);
 	}
 
 	/* detect JOIN channel */
@@ -84,10 +83,7 @@ keitai_start(struct tparam *th)
 	}
 
 	if ((s = strstr(th->l_buff, "PART"))) {
-		strcpy(a3, s + 5);
-		sscanf(th->l_buff, ":%s PART %s :%*[^,]", a1, a3);
-		if (strcmp(th->real_nickname, a1) == 0)
-			part_recv(th, a3);
+		part_recv(th);
  	}
 
 	/* catch PRIVMSGs */
@@ -97,7 +93,9 @@ keitai_start(struct tparam *th)
 
 	/* catch QUIT */
 	if ((s = strstr(th->l_buff, "QUIT"))) {
+#ifdef DEBUG
 		printf("QUIT:%s\n", th->l_buff);
+#endif
 	}
 
 	/* detect TOPIC */
@@ -115,7 +113,9 @@ keitai_start(struct tparam *th)
 
 	/* MODE */
 	if ((s = strstr(th->l_buff, "MODE"))) {
+#ifdef DEBUG
 		printf("MODE:%s\n", th->l_buff);
+#endif
 	}
 
 	/* NAMES */
@@ -134,7 +134,7 @@ int priv_recv(struct tparam *th)
 {
 	time_t t = time(NULL);
 	struct tm* tm;
-	char id[40];
+	char id[IRC_MAX];
 	char channel[C_NAME], channel2[C_NAME];
 	char message[IRC_MAX * 2];
 	char message2[IRC_MAX * 2]; /* include &lt,&gt charactor */
@@ -211,18 +211,18 @@ int priv_recv(struct tparam *th)
 	if (strstr(th->real_nickname, id)) { /* own messages */
 		sprintf(th->
 			data[ch_number][th->history_count[ch_number]],
-			"%02d:%02d %s<  %s<br>",
+			"%02d:%02d &gt;%s&lt;  %s<br>",
 			tm->tm_hour, tm->tm_min,id, message2);
 		th->read_count[ch_number]++;
 	} else {
 		sprintf(th->
 			data[ch_number][th->history_count[ch_number]],
-			"%02d:%02d %s> %s<br>",
+			"%02d:%02d &lt;%s&gt; %s<br>",
 			tm->tm_hour, tm->tm_min,id, message2);
 	}
 	th->history_count[ch_number]++;
 
-#ifdef DEBUG
+#ifdef DEBUG2
 	printf("%d: %s | %s\n", (th->history_count[ch_number] - 1), channel2,
 		th->data[ch_number][th->history_count[ch_number] - 1]);
 #endif
@@ -233,7 +233,7 @@ int priv_recv(struct tparam *th)
 int names_recv(struct tparam *th, char *channel, char *names)
 {
 	int n = 0;
-	char buf[IRC_MAX];
+	char buf[IRC_MAX * 2];
 	char channel2[C_NAME];
 
 	/* channel;  #hoge:*.jp -> %hoge */
@@ -281,13 +281,26 @@ int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 	return (0);
 }
 
-int part_recv(struct tparam *th, char *channel)
+int part_recv(struct tparam *th)
 {
 	int i, j, match = 255;
-	char channel2[C_NAME];
+	char id[IRC_MAX];
+	char channel[C_NAME], channel2[C_NAME];
 
+	/* zero clear */
+	memset(channel,  0, sizeof(channel));
 	memset(channel2, 0, sizeof(channel2));
 
+	/* get PART */
+	sscanf(th->l_buff, ":%s PART %s :%*[^,]",
+		id, channel);
+
+	/* send NAMES command */
+	if (strcmp(th->real_nickname, id) != 0) {
+		send_names(th, channel);
+		return (0);
+	}
+
 	/* channel;  #hoge:*.jp -> %hoge */
 	channel_encode(channel2, channel);
 
@@ -347,8 +360,12 @@ int join_recv(struct tparam *th, char *channel)
 	int i, n = 0;
 	char channel2[C_NAME];
 
+	/* zero clear */
 	memset(channel2, 0, sizeof(channel2));
 
+	/* send NAMES command */
+	send_names(th, channel);
+
 	/* channel;  #hoge:*.jp -> %hoge */
 	channel_encode(channel2, channel);
 
@@ -373,19 +390,64 @@ int join_recv(struct tparam *th, char *channel)
 	return (n);
 }
 
-int ping_recv (struct tparam *th, char *server)
+int ping_recv (struct tparam *th)
 {
-	char data[IRC_MAX];	
+	char server[IRC_MAX];
 
-	/* transfer message to data buffer */
-	sprintf(data, "PONG %s\r\n", server);
+	/* zero clear */
+	memset(server,  0, sizeof(server));
+
+	/* get PING */
+	sscanf(th->l_buff, "PING :%[^\n]", server);
+
+	/* wait for flags clear */
+	while ((!th->t_empty) || (th->t_lock)) {
+		usleep(10000); /* 10ms */
+	}
+	th->t_lock = 1;	/* now writing */
 
 	/* transfer message */
-	send_msg(th->socket_number, data);
+	sprintf(th->postdata, "PONG %s\r\n", server);
 
+	/* clear trans lock and empty flag */
+	th->t_empty = 0;
+	th->t_lock = 0;
+
+	return (0);
+}
+
+int nick_recv(struct tparam *th)
+{
+	char old_nickname[NAME_LEN];
+	char new_nickname[NAME_LEN];
+
+	sscanf(th->l_buff, ":%[^!]!%*s NICK :%[^,]",
+		old_nickname, new_nickname);
+
+	if (strcmp(th->real_nickname, old_nickname) == 0) {
+		strcpy(th->real_nickname, new_nickname);
 #ifdef DEBUG
-	printf("DEBUG PONG -> %s\n", server);
+	printf("NICK:%s -> %s\n", old_nickname, th->real_nickname);
 #endif
+	}
+
+	return (0);
+}
+
+int send_names(struct tparam *th, char *channel)
+{
+	/* wait for flags clear */
+	while ((!th->t_empty) || (th->t_lock)) {
+		usleep(10000); /* 10ms */
+	}
+	th->t_lock = 1;	/* now writing */
+
+	/* transfer message */
+	sprintf(th->postdata, "NAMES %s\r\n", channel);
+
+	/* clear trans lock and empty flag */
+	th->t_empty = 0;
+	th->t_lock = 0;
 
 	return (0);
 }
