@@ -1,5 +1,5 @@
-/* $Id: kircd.h,v 1.8 2005/12/10 13:09:55 ichiro Exp $ */
-#define DEBUG
+/* $Id: kircd.h,v 1.14 2005/12/11 20:18:59 ichiro Exp $ */
+/* #define DEBUG */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -43,22 +43,24 @@
 #define CLIENT 0
 #define SERVER 1
 
-#define SBUFLEN 4096
-#define LBUFLEN 4096
-#define HTTPBUF 4096
+#define SBUFLEN 8192
+#define LBUFLEN 8192
+#define HTTPBUF 8192
 
 #define CONFSEP ";\n"
 
 /* channel */
 #define CH_MAX 20
+#define C_NAME 40
 
 /* max cache line */
 #define C_HISTORY_NUM 31
 
-#define C_NAME 40
+#define NAME_LEN 10
 
 /* rfc1459, max length of IRC message is 512 byte */
-#define IRC_MAX 515
+/* #define IRC_MAX 515 */
+#define IRC_MAX 1024
 
 struct tparam {
 	int socket_number;
@@ -79,7 +81,7 @@ struct tparam {
 	int cookie_expire;
 	char name[CH_MAX][C_NAME];
 	int  ch_count;
-	char data[CH_MAX][C_HISTORY_NUM][IRC_MAX];
+	char data[CH_MAX][C_HISTORY_NUM][IRC_MAX * 2];
 	int  history_count[CH_MAX];
 	int  read_count[CH_MAX];
 	char topic[CH_MAX][IRC_MAX];
@@ -88,7 +90,7 @@ struct tparam {
 	/* transfer buffer */
 	int  t_empty;	/* trans buffer empty */
 	int  t_lock;	/* trans buffer writing */
-	char postdata[IRC_MAX];
+	char postdata[IRC_MAX * 2];
 
 	/* auth (copy) */
 	char auth_user[40];
@@ -122,9 +124,12 @@ extern int readconf(unsigned char *, struct config *);
 extern int keitai_start(struct tparam *);
 extern int priv_recv(struct tparam *);
 extern int topic_recv(struct tparam *, char *, char *, char *);
-extern int part_recv(struct tparam *, char *);
+extern int part_recv(struct tparam *);
 extern int join_recv(struct tparam *, char *);
 extern int names_recv(struct tparam *, char *, char *);
+extern int ping_recv(struct tparam *);
+extern int send_names(struct tparam *, char *);
+extern int nick_recv(struct tparam *);
 
 extern int url_decode_jis(char *, char *);
 extern int url_decode_rawdata(char *, char *);
